/*******************************************************************************
 * University of Illinois/NCSA
 * Open Source License
 *
 * Copyright (c) 2010 , NCSA.  All rights reserved.
 *
 * Developed by:
 * Cyberenvironments and Technologies (CET)
 * http://cet.ncsa.illinois.edu/
 *
 * National Center for Supercomputing Applications (NCSA)
 * http://www.ncsa.illinois.edu/
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal with the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimers.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimers in the
 *   documentation and/or other materials provided with the distribution.
 * - Neither the names of CET, University of Illinois/NCSA, nor the names
 *   of its contributors may be used to endorse or promote products
 *   derived from this Software without specific prior written permission.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 *******************************************************************************/
package edu.uiuc.ncsa.cet.bean;

/**
 * This is a minimal dataset. This is used to store information about previews
 * created and associated with the real dataset.
 * 
 * @author Rob Kooper
 * 
 */
@SuppressWarnings("serial")
public class PreviewVideoBean extends PreviewBean
{
    /** width of the preview video */
    private long             width  = 0;

    /** height of the preview video */
    private long             height = 0;

    /** preview image associated with the video */
    private PreviewImageBean previewImage;

    /**
     * Create a new instance of the artifact.
     */
    public PreviewVideoBean()
    {
    }

    /**
     * Get the width of the preview video.
     * 
     * @return width of the preview video.
     */
    public long getWidth()
    {
        return width;
    }

    /**
     * Sets the width of the preview video.
     * 
     * @param width
     *            the width of the preview video.
     */
    public void setWidth( long width )
    {
        this.width = width;
    }

    /**
     * Get the height of the preview video.
     * 
     * @return height of the preview video.
     */
    public long getHeight()
    {
        return height;
    }

    /**
     * Sets the height of the preview video.
     * 
     * @param height
     *            the height of the preview video.
     */
    public void setHeight( long height )
    {
        this.height = height;
    }

    /**
     * Returns the preview image that is associated with this video.
     * 
     * @return the preview image associated with this video.
     */
    public PreviewImageBean getPreviewImage()
    {
        return previewImage;
    }

    /**
     * Sets the preview image associated with this preview.
     * 
     * @param previewImage
     *            the preview image to be shown when video is selected.
     */
    public void setPreviewImage( PreviewImageBean previewImage )
    {
        this.previewImage = previewImage;
    }

}
