/*******************************************************************************
 * University of Illinois/NCSA
 * Open Source License
 *
 * Copyright (c) 2010 , NCSA.  All rights reserved.
 *
 * Developed by:
 * Cyberenvironments and Technologies (CET)
 * http://cet.ncsa.illinois.edu/
 *
 * National Center for Supercomputing Applications (NCSA)
 * http://www.ncsa.illinois.edu/
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal with the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimers.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimers in the
 *   documentation and/or other materials provided with the distribution.
 * - Neither the names of CET, University of Illinois/NCSA, nor the names
 *   of its contributors may be used to endorse or promote products
 *   derived from this Software without specific prior written permission.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 *******************************************************************************/
package edu.uiuc.ncsa.cet.bean;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import edu.uiuc.ncsa.cet.bean.dse.PublishedWorkflowBean;

public class ScenarioBean extends CETBean implements Serializable, CETBean.TitledBean {

	/**
	 * Used for serialization of object.
	 */
	private static final long serialVersionUID = 1L;

	private String title = "";

	private String description = "";

	/**
	 * Ordered list of visualizations in scenario.
	 * 
	 */
	private List<VisualizationBean> visualizations = new ArrayList<VisualizationBean>();

	/**
	 * Ordered list of published workflows associated with this scenario.
	 * 
	 */
	private List<PublishedWorkflowBean> publishedWorkflows = new ArrayList<PublishedWorkflowBean>();

	/**
	 * Unordered list of data sets associated with this scenario.
	 * 
	 */
	private Set<DatasetBean> dataSets = new HashSet<DatasetBean>();

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public List<VisualizationBean> getVisualizations() {
		return visualizations;
	}

	public void setVisualizations(Collection<VisualizationBean> visualizations) {
		this.visualizations.clear();
		if (visualizations != null) {
			this.visualizations.addAll(visualizations);
		}
	}

	public void addVisualization(VisualizationBean visualizationBean) {
		if (visualizationBean != null) {
			this.visualizations.add(visualizationBean);
		}
	}

	public void removeVisualization(VisualizationBean visualizationBean) {
		this.visualizations.remove(visualizationBean);
	}

	public Set<DatasetBean> getDataSets() {
		return dataSets;
	}

	public void setDataSets(Collection<DatasetBean> dataSets) {
		this.dataSets.clear();
		if (dataSets != null) {
			this.dataSets.addAll(dataSets);
		}
	}

	public void addDataSet(DatasetBean artifactBean) {
		if (artifactBean != null) {
			this.dataSets.add(artifactBean);
		}
	}

	public void remoteDataSet(DatasetBean artifactBean) {
		this.dataSets.remove(artifactBean);
	}

	public List<PublishedWorkflowBean> getPublishedWorkflows() {
		return publishedWorkflows;
	}

	public void setPublishedWorkflows(
			List<PublishedWorkflowBean> publishedWorkflows) {
		this.publishedWorkflows = publishedWorkflows;
	}

	public void addPublishedWorkflow(PublishedWorkflowBean publishedWorkflowBean) {
		this.publishedWorkflows.add(publishedWorkflowBean);
	}

}
