/*******************************************************************************
 * University of Illinois/NCSA
 * Open Source License
 *
 * Copyright (c) 2010 , NCSA.  All rights reserved.
 *
 * Developed by:
 * Cyberenvironments and Technologies (CET)
 * http://cet.ncsa.illinois.edu/
 *
 * National Center for Supercomputing Applications (NCSA)
 * http://www.ncsa.illinois.edu/
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal with the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimers.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimers in the
 *   documentation and/or other materials provided with the distribution.
 * - Neither the names of CET, University of Illinois/NCSA, nor the names
 *   of its contributors may be used to endorse or promote products
 *   derived from this Software without specific prior written permission.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 *******************************************************************************/
package edu.uiuc.ncsa.cet.bean.dse;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import edu.uiuc.ncsa.cet.bean.CETBean;
import edu.uiuc.ncsa.cet.bean.PersonBean;
import edu.uiuc.ncsa.cet.bean.VisualizationBean;
import edu.uiuc.ncsa.cet.bean.workflow.WorkflowBean;

/**
 * Given a workflow, a published workflow or computation represents a version of
 * the workflow on the web in which only certain inputs, outputs and parameters
 * are available. Specific web widgets wrap input, outputs and parameters in a
 * web meaningful way.
 * 
 * @author Luigi Marini lmarini@ncsa.uiuc.edu
 * 
 */
public class PublishedWorkflowBean extends CETBean {

	private static final long serialVersionUID = 1L;

	private String title;

	private String description;

	private Date dateCreated = new Date();

	private PersonBean creator = new PersonBean();

	private WorkflowBean workflow;

	private Set<String> workflowExecutionsURI = new HashSet<String>();

	private Set<String> markedParametersURI = new HashSet<String>();

	private Set<String> markedInputsURI = new HashSet<String>();

	private Set<String> markedOutputsURI = new HashSet<String>();

	private Set<VisualizationBean> visualizations = new HashSet<VisualizationBean>();

	private List<FormInputBean> inputWidgets = new ArrayList<FormInputBean>();

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public WorkflowBean getWorkflow() {
		return workflow;
	}

	public void setWorkflow(WorkflowBean workflow) {
		this.workflow = workflow;
	}

	public Set<String> getWorkflowExecutionsURI() {
		return workflowExecutionsURI;
	}

	public void setWorkflowExecutionsURI(Set<String> workflowExecutionsURI) {
		this.workflowExecutionsURI = workflowExecutionsURI;
	}

	public void addWorkflowExecutionsURI(String workflowExecutionsURI) {
		this.workflowExecutionsURI.add(workflowExecutionsURI);
	}

	public Set<String> getMarkedParametersURI() {
		return markedParametersURI;
	}

	public void setMarkedParametersURI(Set<String> publishedParametersURI) {
		this.markedParametersURI = publishedParametersURI;
	}

	public Set<String> getMarkedInputsURI() {
		return markedInputsURI;
	}

	public void setMarkedInputsURI(Set<String> publishedInputsURI) {
		this.markedInputsURI = publishedInputsURI;
	}

	public Set<String> getMarkedOutputsURI() {
		return markedOutputsURI;
	}

	public void setMarkedOutputsURI(Set<String> markedOutputsURI) {
		this.markedOutputsURI = markedOutputsURI;
	}

	public Set<VisualizationBean> getVisualizations() {
		return visualizations;
	}

	public void setVisualizations(Set<VisualizationBean> visualizations) {
		this.visualizations = visualizations;
	}

	public void addVisualization(VisualizationBean visualization) {
		this.visualizations.add(visualization);
	}

	public List<FormInputBean> getInputWidgets() {
		return inputWidgets;
	}

	public void setInputWidgets(List<FormInputBean> inputWidgets) {
		this.inputWidgets = inputWidgets;
	}

	public void addInputWidget(FormInputBean inputWidget) {
		this.inputWidgets.add(inputWidget);
	}

	public Date getDateCreated() {
		return dateCreated;
	}

	public void setDateCreated(Date dateCreated) {
		this.dateCreated = dateCreated;
	}

	public PersonBean getCreator() {
		return creator;
	}

	public void setCreator(PersonBean creator) {
		this.creator = creator;
	}

}
